@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "25.0.2-beta+10-ea" },
-            { "jdk", "25.0.2" },
-            { "release", "25.0.2-beta" },
+            { "full", "25-beta+30-ea" },
+            { "jdk", "25" },
+            { "release", "25-beta" },
         };
     }
 }
